<?=
/**
* @package load module into article
* @version 1.0
* @copyright Copyright (C) 2011-2024 RumbleTalk. All rights reserved.
* @license GPL
* @author https://www.rumbletalk.com/
* @joomla Joomla is Free Software
*/

// No direct access.
defined('_JEXEC') or die;

jimport('joomla.plugin.plugin');
jimport('joomla.html.parameter.');

use \Joomla\Component\Fields\Administrator\Helper\FieldsHelper;
use \Joomla\CMS\Uri\Uri;

defined('RUMBLETALKCHAT_SHORTCODE') or define('RUMBLETALKCHAT_SHORTCODE', '{rumbletalkchat}');

/**
 * Rumbletalkchat plugin class.
 */
class plgContentRumbletalkchat extends JPlugin
{
	/**
	 * Plugin that insert RumbleTalk Chat into articles
	 *
	 * @param	string	The context of the content being passed to the plugin.
	 * @param	mixed	An object with a "text" property
	 * @param	array	Additional parameters.
	 * @param	int	Optional page number. Unused. Defaults to zero.
	 * @return	boolean	True on success.
	 */
	public function onContentPrepare($context, &$row, &$params, $page = 0)
	{
            if (!substr_count($row->text, RUMBLETALKCHAT_SHORTCODE)) {
                return true;
            }

            $style = null;
            $output = null;

            $code = $this->params->get('rumbletalkchat_code', null);
            $width = $this->params->get('rumbletalkchat_width', null);
            $height = $this->params->get('rumbletalkchat_height', null);

            $style .= !empty($width) ? 'width: ' . $width . ';': null;
            $style .= !empty($height) ? 'height: ' . $height . ';' : null;
            $style = !empty($style) ? ' style="' . $style . '"' : null;

            $output .= '<div id="rt-'.md5($code).'"' . $style . '>';
            $user = JFactory::getUser();
            $integration = $this->params->get('autologin', 1);

            // first line might not be necessary depending on Joomla version
            $customFields = FieldsHelper::getFields('com_users.user', JFactory::getUser(), true);

            // These additional codes are needed to retrieve the User's profile image
            $fullLink = $customFields[0]->rawvalue;
            $links = json_decode($fullLink); 
            $imageFile = $links->imagefile;
            
            if (!is_null($code)) {
                ob_start();
                if($user->id && ($integration == 1)){
                    ?>
                    <script type = "text/javascript">
                        (function(g, v, w, d, s, a, b) {
                            w['rumbleTalkMessageQueueName'] = g;
                            w[g] = w[g] ||
                            function() {
                            (w[g].q = w[g].q || []).push(arguments)
                            };
                            a = d.createElement(s);
                            b = d.getElementsByTagName(s)[0];
                            a.async = 1;
                            a.src = 'https://d1pfint8izqszg.cloudfront.net/api/' + v + '/sdk.js';
                            b.parentNode.insertBefore(a, b);
                        })('rtmq', 'v1.0.0', window, document, 'script'); 
                    </script>
                    
                    <script type="text/javascript">
                        rtmq(
                            'login',
                            {
                                hash: '<?= $code; ?>',
                                image: '<?= JURI::root().$imageFile; ?>',
                                username: '<?= $user->name; ?>'
                            }
                        );    
                    </script>
            
                    <?php
                }
                $baseURL = JURI::root();
                $localURL = '/localhost/i';
                $rumbletalkURL = '/rumbletalk/i';

                if (preg_match($localURL, $baseURL) || 
                    preg_match($rumbletalkURL, $baseURL)) {
                    $output .= '<script type="text/javascript" src="https://rumbletalk.com/client/?' . $code . '"></script>';
                } else {
                    $output .= '<script type="text/javascript" src="https://rumbletalk.com/client/chat.php?' . $code . '"></script>';
                }

            } else {
                $output .= 'Empty RumbleTalk Chat Code, please configure RumbleTalk Chat plug-in.';
            }

            $output .= '</div>';

            $row->text = str_replace(RUMBLETALKCHAT_SHORTCODE, $output, $row->text);
            
            $output .= ob_get_clean();

            return true;
        }
}
